import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:okane/database/sqlite.dart';
import 'package:okane/i18n/strings.g.dart';

class EditBudgetPopup extends StatefulWidget {
  final BudgetsDto budget;

  final VoidCallback onDone;

  const EditBudgetPopup({
    required this.budget,
    required this.onDone,
    super.key,
  });

  @override
  EditBudgetState createState() => EditBudgetState();
}

class EditBudgetState extends State<EditBudgetPopup> {
  final _budgetNameEditController = TextEditingController();

  late bool _includeOtherSpendings;

  @override
  void initState() {
    super.initState();

    _budgetNameEditController.text = widget.budget.budget.name;
    _includeOtherSpendings = widget.budget.budget.includeOtherSpendings;
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        TextField(
          decoration: InputDecoration(
            hintText: t.pages.budgets.addBudget.budgetNameHint,
          ),
          controller: _budgetNameEditController,
        ),
        Row(
          children: [
            Text(t.pages.budgets.addBudget.includeOtherSpendings),
            Switch(
              value: _includeOtherSpendings,
              onChanged: (value) {
                setState(() => _includeOtherSpendings = value);
              },
            ),
          ],
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            OutlinedButton(
              onPressed: () async {
                if (_budgetNameEditController.text.isEmpty) {
                  return;
                }
                if (_budgetNameEditController.text ==
                        widget.budget.budget.name &&
                    _includeOtherSpendings ==
                        widget.budget.budget.includeOtherSpendings) {
                  widget.onDone();
                  return;
                }

                await GetIt.I.get<OkaneDatabase>().budgetsDao.upsertBudget(
                  widget.budget.budget
                      .copyWith(
                        name: _budgetNameEditController.text,
                        includeOtherSpendings: _includeOtherSpendings,
                      )
                      .toCompanion(false),
                );
                widget.onDone();
              },
              child: Text(t.modals.save),
            ),
          ],
        ),
      ],
    );
  }
}
